@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -46,9 +46,7 @@ ConfigureCustomSettingWidget::ConfigureCustomSettingWidget(QWidget *parent)
     categoryLayout->addWidget(mEnableCategory);
 }
 
-ConfigureCustomSettingWidget::~ConfigureCustomSettingWidget()
-{
-}
+ConfigureCustomSettingWidget::~ConfigureCustomSettingWidget() = default;
 
 void ConfigureCustomSettingWidget::slotTextChanged(const QString &text)
 {
